pub struct FilledShape { /* private fields */ }Expand description
A shape filled with a color, resolved to ResolvedShape.
Implementations
Sourceimpl FilledShape
impl FilledShape
Sourcepub fn new(shape: impl Shape, fill: impl Into<Color>) -> Self
pub fn new(shape: impl Shape, fill: impl Into<Color>) -> Self
Creates a new filled shape from a shape and color.
Sourcepub fn commands(&self) -> &[PathCommand]
pub fn commands(&self) -> &[PathCommand]
Returns the path commands.
Sourcepub fn morph_to(self, target: impl ShapeExt) -> MorphShape
pub fn morph_to(self, target: impl ShapeExt) -> MorphShape
Creates a morphing shape animation from this shape to another built-in shape.
Morphing currently supports SDF-backed built-in shapes:
Rectangle, Circle, Ellipse, RoundedRectangle, UnevenRoundedRectangle, Capsule.