pub enum PathCommand {
MoveTo {
x: f32,
y: f32,
},
LineTo {
x: f32,
y: f32,
},
QuadTo {
cx: f32,
cy: f32,
x: f32,
y: f32,
},
CubicTo {
c1x: f32,
c1y: f32,
c2x: f32,
c2y: f32,
x: f32,
y: f32,
},
Arc {
cx: f32,
cy: f32,
rx: f32,
ry: f32,
start: f32,
sweep: f32,
},
Close,
}Expand description
A single path command for drawing shapes.
All coordinates are normalized (0.0-1.0) and scale with view bounds. Native backends convert these to absolute coordinates based on view size.
Variants
MoveTo
Move to a position without drawing.
LineTo
Draw a straight line to a position.
QuadTo
Draw a quadratic bezier curve.
CubicTo
Draw a cubic bezier curve.
Fields
Arc
Draw an arc.
Fields
Close
Close the current subpath by drawing a line to the start.